@@ -5,6 +5,7 @@ from apminsight.logger import agentlogger
 from apminsight.agentfactory import get_agent
 
 def send_req(path_uri, payload):
+    response = ''
     response_data = {}
     try:
         config = get_agent().get_config()
@@ -16,8 +17,8 @@ def send_req(path_uri, payload):
         agentlogger.info('sending request to ' + url)
         if config.is_payload_print_enabled():
             agentlogger.info('payload :'+ payload_str)
-
-        response = requests.post(complete_url, data=payload_str, headers=headers)
+        proxy_details = config.get_proxy_details() if not False else {}
+        response = requests.post(complete_url, data=payload_str, headers=headers, proxies = proxy_details)
         response_data = response.json()
     except Exception:
         agentlogger.exception(path_uri+' req error '+ str(response))
