@@ -8,5 +8,7 @@ __all__ = [
     'psycopg2',
     'pymemcache',
     'redis',
-    'sqlite'
+    'sqlite',
+    'cassandra',
+    'memcache'
 ]
\ No newline at end of file
