@@ -2,6 +2,7 @@
 from apminsight import constants
 from apminsight.util import is_non_empty_string
 from apminsight.agentfactory import get_agent
+from apminsight.logger import agentlogger
 
 def extract_query(tracker, args=(), kwargs={}, return_value=None):
     threshold = get_agent().get_threshold()
@@ -14,7 +15,12 @@ def extract_query(tracker, args=(), kwargs={}, return_value=None):
         elif isinstance(args[1], (bytes, bytearray)):
             query = args[1].decode("utf-8")
             tracker.set_info({ 'query' : query})
-
+        try:
+            host= args[0].connection.host
+            port= args[0].connection.port
+            tracker.set_info({'host':host,'port':port})
+        except:
+            agentlogger.exception("Extracting host info from MYSQL query")
 
 module_info = {
     'pymysql' : [
