@@ -9,7 +9,7 @@ module_info = {
             constants.component_str : constants.postgres_comp,
             constants.wrapper_str : ConnectionProxy.instrument_conn,
             constants.default_host : constants.localhost,
-            constants.default_port : '5432'
+            constants.default_port : 5432
         }
     ]
 }
