@@ -14,8 +14,8 @@ def extract_info(tracker, args=(), kwargs={}, return_value=None):
 
         if hasattr(args[0], 'server'):
             server = args[0].server
-            if isinstance(args, (list, tuple)) and len(args)==2:
-                tracker.set_info({'host' : server[0], 'port' : str(server[1])})
+            if isinstance(server, (list, tuple)) and len(server)==2:
+                tracker.set_info({'host' : server[0], 'port' : server[1]})
 
 
 module_info = {
