@@ -3,7 +3,7 @@ from apminsight import constants
 from apminsight.util import is_non_empty_string
 from apminsight.metric.tracker import Tracker
 from apminsight.context import get_cur_tracker
-
+from apminsight.logger import agentlogger
 def extract_info(tracker, args):
     if not isinstance(tracker, Tracker):
         return
@@ -17,15 +17,19 @@ def extract_info(tracker, args):
 
         if hasattr(args[0], 'host') and hasattr(args[0], 'port'):
             host = getattr(args[0], 'host')
-            port = str(getattr(args[0], 'port'))
+            port = getattr(args[0], 'port')
             tracker.set_info({'host' : host, 'port' : port})
         
 
 def wrap_send_command(actual, module, method_info):
     def redis_wrapper(*args, **kwargs):
-        tracker = get_cur_tracker()
-        extract_info(tracker, args)
-        return actual(*args, **kwargs)
+        try:
+            tracker = get_cur_tracker()
+            extract_info(tracker, args)
+        except:
+            agentlogger.exception("While extracting Redis call info")
+        finally:
+            return actual(*args, **kwargs)
 
     return redis_wrapper
 
