@@ -3,12 +3,18 @@ import os
 import sys
 import logging
 from logging.handlers import RotatingFileHandler
-from apminsight.constants import agent_logger_name, logs_dir, base_dir, log_name, log_format
+from apminsight.util import is_empty_string
+from apminsight.constants import agent_logger_name, \
+    logs_dir, base_dir, log_name, log_format, apm_logs_dir
 
 agentlogger = None
 
 def check_and_create_dirs():
-    base_path = os.path.join(os.getcwd(), base_dir)
+    cus_logs_dir = os.getenv(apm_logs_dir, '')
+    if(is_empty_string(cus_logs_dir)):
+        cus_logs_dir = os.getcwd()
+
+    base_path = os.path.join(cus_logs_dir, base_dir)
     logs_path = os.path.join(base_path, logs_dir)
 
     if not os.path.exists(logs_path):
